rasmus                                   Sun, 15 May 2011 06:09:21 +0000

Revision: http://svn.php.net/viewvc?view=revision&revision=311042

Log:
Drop support for autoconf < 2.60 in trunk and the
new PHP_5_4 branch. autoconf >= 2.60 should finally
be working now.

Changed paths:
    U   php/php-src/branches/PHP_5_4/build/buildcheck.sh
    U   php/php-src/branches/PHP_5_4/configure.in
    U   php/php-src/branches/PHP_5_4/ext/standard/config.m4
    U   php/php-src/branches/PHP_5_4/scripts/php-config.in
    U   php/php-src/branches/PHP_5_4/scripts/phpize.in
    U   php/php-src/branches/PHP_5_4/scripts/phpize.m4
    U   php/php-src/trunk/build/buildcheck.sh
    U   php/php-src/trunk/configure.in
    U   php/php-src/trunk/ext/standard/config.m4
    U   php/php-src/trunk/scripts/php-config.in
    U   php/php-src/trunk/scripts/phpize.in
    U   php/php-src/trunk/scripts/phpize.m4

Modified: php/php-src/branches/PHP_5_4/build/buildcheck.sh
===================================================================
--- php/php-src/branches/PHP_5_4/configure.in	2011-05-15 05:49:34 UTC (rev 311041)
+++ php/php-src/branches/PHP_5_4/configure.in	2011-05-15 06:09:21 UTC (rev 311042)
@@ -1,28 +1,6 @@
 ## $Id$ -*- autoconf -*-
 dnl ## Process this file with autoconf to produce a configure script.

-divert(1)
-
-dnl ## Diversion 1 is the autoconf + automake setup phase. We also
-dnl ## set the PHP version, deal with platform-specific compile
-dnl ## options and check for the basic compile tools.
-
-dnl ## Diversion 2 is the initial checking of OS features, programs,
-dnl ## libraries and so on.
-
-dnl ## In diversion 3 we check for compile-time options to the PHP
-dnl ## core and how to deal with different system dependencies.
-dnl ## This includes whether debugging or short tags are enabled
-dnl ## and the default behaviour of php.ini options.
-dnl ## This is also where an SAPI interface is selected (choosing between
-dnl ## Apache module, CGI etc.)
-
-dnl ## In diversion 4 we check user-configurable general settings.
-
-dnl ## In diversion 5 we check which extensions should be compiled.
-dnl ## All of these are normally in the extension directories.
-dnl ## Diversion 5 is the last one.  Here we generate files and clean up.
-
 dnl include Zend specific macro definitions first
 dnl -------------------------------------------------------------------------
 sinclude(Zend/acinclude.m4)
@@ -30,8 +8,9 @@
 dnl Basic autoconf + automake initialization, generation of config.nice.
 dnl -------------------------------------------------------------------------

-AC_PREREQ(2.13)
+AC_PREREQ(2.60)
 AC_INIT(README.SVN-RULES)
+AC_PRESERVE_HELP_ORDER

 PHP_CONFIG_NICE(config.nice)

@@ -289,15 +268,6 @@
 sinclude(TSRM/threads.m4)
 sinclude(TSRM/tsrm.m4)

-
-divert(2)
-
-dnl ## Diversion 2 is where we set PHP-specific options and come up
-dnl ## with reasonable default values for them. We check for pthreads here
-dnl ## because the information is needed by the SAPI configuration.
-dnl ## This is also where an SAPI interface is selected (choosing between
-dnl ## Apache module, CGI etc.)
-
 dnl .
 dnl -------------------------------------------------------------------------

@@ -343,13 +313,6 @@
   PTHREADS_FLAGS
 fi

-divert(3)
-
-dnl ## In diversion 3 we check for compile-time options to the PHP
-dnl ## core and how to deal with different system dependencies.
-dnl ## This includes whether debugging or short tags are enabled
-dnl ## and the default behaviour of php.ini options.
-
 dnl Starting system checks.
 dnl -------------------------------------------------------------------------

@@ -689,10 +652,6 @@
   PHP_CRYPT_R_STYLE
 fi

-divert(4)
-
-dnl ## In diversion 4 we check user-configurable general settings.
-
 dnl General settings.
 dnl -------------------------------------------------------------------------
 PHP_CONFIGURE_PART(General settings)
@@ -927,11 +886,6 @@
   AC_MSG_RESULT([using system default])
 fi

-divert(5)
-
-dnl ## In diversion 5 we check which extensions should be compiled.
-dnl ## All of these are normally in the extension directories.
-
 dnl Extension configuration.
 dnl -------------------------------------------------------------------------


Modified: php/php-src/branches/PHP_5_4/ext/standard/config.m4
===================================================================
--- php/php-src/branches/PHP_5_4/ext/standard/config.m4	2011-05-15 05:49:34 UTC (rev 311041)
+++ php/php-src/branches/PHP_5_4/ext/standard/config.m4	2011-05-15 06:09:21 UTC (rev 311042)
@@ -1,7 +1,5 @@
 dnl $Id$ -*- autoconf -*-

-divert(3)dnl
-
 dnl
 dnl Check if flush should be called explicitly after buffered io
 dnl
@@ -342,8 +340,6 @@
 AC_CHECK_FUNCS(getcwd getwd asinh acosh atanh log1p hypot glob strfmon nice fpclass isinf isnan mempcpy strpncpy)
 AC_FUNC_FNMATCH

-divert(5)dnl
-
 dnl
 dnl Check if there is a support means of creating a new process
 dnl and defining which handles it receives

Modified: php/php-src/branches/PHP_5_4/scripts/php-config.in
===================================================================
--- php/php-src/branches/PHP_5_4/scripts/php-config.in	2011-05-15 05:49:34 UTC (rev 311041)
+++ php/php-src/branches/PHP_5_4/scripts/php-config.in	2011-05-15 06:09:21 UTC (rev 311042)
@@ -2,6 +2,7 @@

 SED="@SED@"
 prefix="@prefix@"
+datarootdir="@datarootdir@"
 exec_prefix="@exec_prefix@"
 version="@PHP_VERSION@"
 vernum="@PHP_VERSION_ID@"

Modified: php/php-src/branches/PHP_5_4/scripts/phpize.in
===================================================================
--- php/php-src/branches/PHP_5_4/scripts/phpize.in	2011-05-15 05:49:34 UTC (rev 311041)
+++ php/php-src/branches/PHP_5_4/scripts/phpize.in	2011-05-15 06:09:21 UTC (rev 311042)
@@ -2,6 +2,7 @@

 # Variable declaration
 prefix='@prefix@'
+datarootdir='@datarootdir@'
 exec_prefix="`eval echo @exec_prefix@`"
 phpdir="`eval echo @libdir@`/build"
 includedir="`eval echo @includedir@`/php"

Modified: php/php-src/branches/PHP_5_4/scripts/phpize.m4
===================================================================
--- php/php-src/branches/PHP_5_4/scripts/phpize.m4	2011-05-15 05:49:34 UTC (rev 311041)
+++ php/php-src/branches/PHP_5_4/scripts/phpize.m4	2011-05-15 06:09:21 UTC (rev 311042)
@@ -1,9 +1,8 @@
 dnl This file becomes configure.in for self-contained extensions.

-divert(1)
-
-AC_PREREQ(2.13)
+AC_PREREQ(2.60)
 AC_INIT(config.m4)
+AC_PRESERVE_HELP_ORDER

 PHP_CONFIG_NICE(config.nice)


Modified: php/php-src/trunk/build/buildcheck.sh
===================================================================
--- php/php-src/trunk/configure.in	2011-05-15 05:49:34 UTC (rev 311041)
+++ php/php-src/trunk/configure.in	2011-05-15 06:09:21 UTC (rev 311042)
@@ -1,28 +1,6 @@
 ## $Id$ -*- autoconf -*-
 dnl ## Process this file with autoconf to produce a configure script.

-divert(1)
-
-dnl ## Diversion 1 is the autoconf + automake setup phase. We also
-dnl ## set the PHP version, deal with platform-specific compile
-dnl ## options and check for the basic compile tools.
-
-dnl ## Diversion 2 is the initial checking of OS features, programs,
-dnl ## libraries and so on.
-
-dnl ## In diversion 3 we check for compile-time options to the PHP
-dnl ## core and how to deal with different system dependencies.
-dnl ## This includes whether debugging or short tags are enabled
-dnl ## and the default behaviour of php.ini options.
-dnl ## This is also where an SAPI interface is selected (choosing between
-dnl ## Apache module, CGI etc.)
-
-dnl ## In diversion 4 we check user-configurable general settings.
-
-dnl ## In diversion 5 we check which extensions should be compiled.
-dnl ## All of these are normally in the extension directories.
-dnl ## Diversion 5 is the last one.  Here we generate files and clean up.
-
 dnl include Zend specific macro definitions first
 dnl -------------------------------------------------------------------------
 sinclude(Zend/acinclude.m4)
@@ -30,8 +8,9 @@
 dnl Basic autoconf + automake initialization, generation of config.nice.
 dnl -------------------------------------------------------------------------

-AC_PREREQ(2.13)
+AC_PREREQ(2.60)
 AC_INIT(README.SVN-RULES)
+AC_PRESERVE_HELP_ORDER

 PHP_CONFIG_NICE(config.nice)

@@ -289,15 +268,6 @@
 sinclude(TSRM/threads.m4)
 sinclude(TSRM/tsrm.m4)

-
-divert(2)
-
-dnl ## Diversion 2 is where we set PHP-specific options and come up
-dnl ## with reasonable default values for them. We check for pthreads here
-dnl ## because the information is needed by the SAPI configuration.
-dnl ## This is also where an SAPI interface is selected (choosing between
-dnl ## Apache module, CGI etc.)
-
 dnl .
 dnl -------------------------------------------------------------------------

@@ -343,13 +313,6 @@
   PTHREADS_FLAGS
 fi

-divert(3)
-
-dnl ## In diversion 3 we check for compile-time options to the PHP
-dnl ## core and how to deal with different system dependencies.
-dnl ## This includes whether debugging or short tags are enabled
-dnl ## and the default behaviour of php.ini options.
-
 dnl Starting system checks.
 dnl -------------------------------------------------------------------------

@@ -689,10 +652,6 @@
   PHP_CRYPT_R_STYLE
 fi

-divert(4)
-
-dnl ## In diversion 4 we check user-configurable general settings.
-
 dnl General settings.
 dnl -------------------------------------------------------------------------
 PHP_CONFIGURE_PART(General settings)
@@ -927,11 +886,6 @@
   AC_MSG_RESULT([using system default])
 fi

-divert(5)
-
-dnl ## In diversion 5 we check which extensions should be compiled.
-dnl ## All of these are normally in the extension directories.
-
 dnl Extension configuration.
 dnl -------------------------------------------------------------------------


Modified: php/php-src/trunk/ext/standard/config.m4
===================================================================
--- php/php-src/trunk/ext/standard/config.m4	2011-05-15 05:49:34 UTC (rev 311041)
+++ php/php-src/trunk/ext/standard/config.m4	2011-05-15 06:09:21 UTC (rev 311042)
@@ -1,7 +1,5 @@
 dnl $Id$ -*- autoconf -*-

-divert(3)dnl
-
 dnl
 dnl Check if flush should be called explicitly after buffered io
 dnl
@@ -342,8 +340,6 @@
 AC_CHECK_FUNCS(getcwd getwd asinh acosh atanh log1p hypot glob strfmon nice fpclass isinf isnan mempcpy strpncpy)
 AC_FUNC_FNMATCH

-divert(5)dnl
-
 dnl
 dnl Check if there is a support means of creating a new process
 dnl and defining which handles it receives

Modified: php/php-src/trunk/scripts/php-config.in
===================================================================
--- php/php-src/trunk/scripts/php-config.in	2011-05-15 05:49:34 UTC (rev 311041)
+++ php/php-src/trunk/scripts/php-config.in	2011-05-15 06:09:21 UTC (rev 311042)
@@ -2,6 +2,7 @@

 SED="@SED@"
 prefix="@prefix@"
+datarootdir="@datarootdir@"
 exec_prefix="@exec_prefix@"
 version="@PHP_VERSION@"
 vernum="@PHP_VERSION_ID@"

Modified: php/php-src/trunk/scripts/phpize.in
===================================================================
--- php/php-src/trunk/scripts/phpize.in	2011-05-15 05:49:34 UTC (rev 311041)
+++ php/php-src/trunk/scripts/phpize.in	2011-05-15 06:09:21 UTC (rev 311042)
@@ -2,6 +2,7 @@

 # Variable declaration
 prefix='@prefix@'
+datarootdir='@datarootdir@'
 exec_prefix="`eval echo @exec_prefix@`"
 phpdir="`eval echo @libdir@`/build"
 includedir="`eval echo @includedir@`/php"

Modified: php/php-src/trunk/scripts/phpize.m4
===================================================================
--- php/php-src/trunk/scripts/phpize.m4	2011-05-15 05:49:34 UTC (rev 311041)
+++ php/php-src/trunk/scripts/phpize.m4	2011-05-15 06:09:21 UTC (rev 311042)
@@ -1,9 +1,8 @@
 dnl This file becomes configure.in for self-contained extensions.

-divert(1)
-
-AC_PREREQ(2.13)
+AC_PREREQ(2.60)
 AC_INIT(config.m4)
+AC_PRESERVE_HELP_ORDER

 PHP_CONFIG_NICE(config.nice)

--- php/php-src/branches/PHP_5_4/build/buildcheck.sh	2011-05-15 05:49:34 UTC (rev 311041)
+++ php/php-src/branches/PHP_5_4/build/buildcheck.sh	2011-05-15 06:09:21 UTC (rev 311042)
@@ -28,32 +28,24 @@
   PHP_AUTOCONF='autoconf'
 fi

 # autoconf 2.13 or newer
 ac_version=`$PHP_AUTOCONF --version 2>/dev/null|head -n 1|sed -e 's/^[^0-9]*//' -e 's/[a-z]* *$//'`
 if test -z "$ac_version"; then
 echo "buildconf: autoconf not found."
-echo "           You need autoconf version 2.13 or newer installed"
+echo "           You need autoconf version 2.60 or newer installed"
 echo "           to build PHP from SVN."
 exit 1
 fi
 IFS=.; set $ac_version; IFS=' '
-if test "$1" = "2" -a "$2" -lt "13" || test "$1" -lt "2"; then
+if test "$1" = "2" -a "$2" -lt "60" || test "$1" -lt "2"; then
 echo "buildconf: autoconf version $ac_version found."
-echo "           You need autoconf version 2.13 or newer installed"
+echo "           You need autoconf version 2.60 or newer installed"
 echo "           to build PHP from SVN."
 exit 1
 else
 echo "buildconf: autoconf version $ac_version (ok)"
 fi

-if test "$1" = "2" && test "$2" -ge "50"; then
-  echo "buildconf: Your version of autoconf likely contains buggy cache code."
-  echo "           Running vcsclean for you."
-  echo "           To avoid this, install autoconf-2.13."
-  ./vcsclean
-  stamp=
-fi
-
 test -n "$stamp" && touch $stamp

 exit 0
@@ -28,32 +28,24 @@
 fi

-# autoconf 2.13 or newer
+# autoconf 2.60 or newer
 ac_version=`$PHP_AUTOCONF --version 2>/dev/null|head -n 1|sed -e 's/^[^0-9]*//' -e 's/[a-z]* *$//'`
 if test -z "$ac_version"; then

Modified: php/php-src/branches/PHP_5_4/configure.in
===================================================================
--- php/php-src/trunk/build/buildcheck.sh	2011-05-15 05:49:34 UTC (rev 311041)
+++ php/php-src/trunk/build/buildcheck.sh	2011-05-15 06:09:21 UTC (rev 311042)
@@ -28,32 +28,24 @@
   PHP_AUTOCONF='autoconf'
 fi

 # autoconf 2.13 or newer
 ac_version=`$PHP_AUTOCONF --version 2>/dev/null|head -n 1|sed -e 's/^[^0-9]*//' -e 's/[a-z]* *$//'`
 if test -z "$ac_version"; then
 echo "buildconf: autoconf not found."
-echo "           You need autoconf version 2.13 or newer installed"
+echo "           You need autoconf version 2.60 or newer installed"
 echo "           to build PHP from SVN."
 exit 1
 fi
 IFS=.; set $ac_version; IFS=' '
-if test "$1" = "2" -a "$2" -lt "13" || test "$1" -lt "2"; then
+if test "$1" = "2" -a "$2" -lt "60" || test "$1" -lt "2"; then
 echo "buildconf: autoconf version $ac_version found."
-echo "           You need autoconf version 2.13 or newer installed"
+echo "           You need autoconf version 2.60 or newer installed"
 echo "           to build PHP from SVN."
 exit 1
 else
 echo "buildconf: autoconf version $ac_version (ok)"
 fi

-if test "$1" = "2" && test "$2" -ge "50"; then
-  echo "buildconf: Your version of autoconf likely contains buggy cache code."
-  echo "           Running vcsclean for you."
-  echo "           To avoid this, install autoconf-2.13."
-  ./vcsclean
-  stamp=
-fi
-
 test -n "$stamp" && touch $stamp

 exit 0
@@ -28,32 +28,24 @@
 fi

-# autoconf 2.13 or newer
+# autoconf 2.60 or newer
 ac_version=`$PHP_AUTOCONF --version 2>/dev/null|head -n 1|sed -e 's/^[^0-9]*//' -e 's/[a-z]* *$//'`
 if test -z "$ac_version"; then

Modified: php/php-src/trunk/configure.in
===================================================================
-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php

Reply via email to